==> haskell-neat-interpolation-0.3.2.4-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: neat-interpolation
version: 0.3.2.4
id: neat-interpolation-0.3.2.4-KLM9IyqTVw1805GYwgV0QC
key: neat-interpolation-0.3.2.4-KLM9IyqTVw1805GYwgV0QC
license: MIT
copyright: (c) 2013, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/neat-interpolation
synopsis: A quasiquoter for neat and simple multiline text interpolation
description:
    A quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.
category: String, QuasiQuotes
abi: 6eaf0931220b376cc1c87d7bf385114f
exposed: True
exposed-modules:
    NeatInterpolation
hidden-modules: NeatInterpolation.Parsing NeatInterpolation.String
import-dirs: /usr/lib/ghc-8.6.4/site-local/neat-interpolation-0.3.2.4
library-dirs: /usr/lib/ghc-8.6.4/site-local/neat-interpolation-0.3.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/neat-interpolation-0.3.2.4
hs-libraries: HSneat-interpolation-0.3.2.4-KLM9IyqTVw1805GYwgV0QC
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    megaparsec-7.0.4-1OY8Qow6d5VBeh9xwvrrAq template-haskell-2.14.0.0
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock
haddock-html: /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-neat-interpolation-0.3.2.4-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: neat-interpolation
version: 0.3.2.4
id: neat-interpolation-0.3.2.4-Exsj1tWMkIuL3nOVuRfVCR
key: neat-interpolation-0.3.2.4-Exsj1tWMkIuL3nOVuRfVCR
license: MIT
copyright: (c) 2013, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/neat-interpolation
synopsis: A quasiquoter for neat and simple multiline text interpolation
description:
    A quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.
category: String, QuasiQuotes
abi: 5134dbc53949fa03a745bf00eace351e
exposed: True
exposed-modules:
    NeatInterpolation
hidden-modules: NeatInterpolation.Parsing NeatInterpolation.String
import-dirs: /usr/lib/ghc-8.6.4/site-local/neat-interpolation-0.3.2.4
library-dirs: /usr/lib/ghc-8.6.4/site-local/neat-interpolation-0.3.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/neat-interpolation-0.3.2.4
hs-libraries: HSneat-interpolation-0.3.2.4-Exsj1tWMkIuL3nOVuRfVCR
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    megaparsec-7.0.4-1MZB8g6cytp9p69U9RRMNX template-haskell-2.14.0.0
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock
haddock-html: /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
